@@ -7,6 +7,7 @@ import pytest_asyncio
 from patchwork.core import Task
 from patchwork.core.client.local import AsyncLocalPublisher, AsyncLocalSubscriber, AsyncLocalBroker, MissingBehaviour
 from patchwork.core.client.serializers.betterproto import BetterprotoSerializer
+from patchwork.core.client.task import FrozenTask
 
 
 @pytest.fixture
@@ -46,7 +47,7 @@ async def test_send(broker):
 async def test_send_payload(broker):
     client = AsyncLocalPublisher(broker=broker)
 
-    task = Task(task_type='test')
+    task = Task(task_type='test', payload=b'')
     task.meta.queue_name = 'test'
     await client._send(b'payload', task)
 
@@ -66,7 +67,7 @@ async def test_send_timeout():
     client = AsyncLocalPublisher(broker=broker)
 
     with pytest.raises(TimeoutError):
-        task = Task(task_type='test')
+        task = Task(task_type='test', payload=b'')
         task.meta.queue_name = 'test'
         await client._send(b'payload', task, timeout=0.01)
 
@@ -80,7 +81,7 @@ async def test_shared_default_queue():
     client_1 = AsyncLocalPublisher()
     client_2 = AsyncLocalSubscriber(queue_names=['test'])
 
-    task = Task(task_type='test')
+    task = Task(task_type='test', payload=b'')
     task.meta.queue_name = 'test'
     await client_1._send(b'payload', task)
     async with client_2:
@@ -125,7 +126,7 @@ async def test_subscribe_on_missing():
     client_2 = AsyncLocalSubscriber(broker=broker, queue_names=['test-missing'])
 
     async def send():
-        task = Task(task_type='test')
+        task = Task(task_type='test', payload=b'')
         task.meta.queue_name = 'test-missing'
         await client_1._send(b'payload', task)
 
@@ -139,3 +140,15 @@ async def test_subscribe_on_missing():
 
     assert payload == b'payload'
     assert meta == {'queue_name': 'test-missing'}
+
+
+@pytest.mark.asyncio
+async def test_task_freeze():
+    t = Task(task_type='test')
+    t._local['foo'] = 'bar'
+
+    frozen = t.freeze()
+    assert frozen.task_type == t.task_type
+    assert frozen._local['foo'] == t._local['foo']
+
+    assert hash(frozen)
\ No newline at end of file
