@@ -98,3 +98,19 @@ async def test_componentconfig_type():
     inst = m.klass.instantiate()
     assert isinstance(inst, TestComponent)
     assert inst.settings.enabled is False
+
+
+class TestSettings(BaseModel):
+    publisher: ComponentConfig
+
+@pytest.mark.asyncio
+async def test_settings_usage():
+    settings = TestSettings(publisher={
+        'engine': 'tests.core.test_config:TestComponent',
+        'options': {
+            'enabled': False
+        }
+    })
+
+    assert settings.publisher.engine is TestComponent
+    assert isinstance(settings.publisher.options, BaseModel)
